@@ -327,13 +327,13 @@ gnm_value_to_py_obj (const GnmEvalPos *eval_pos, const GnmValue *val)
 
     switch (val->type) {
 	case VALUE_BOOLEAN:
-		py_val = py_new_Boolean_object (val->v_bool.val);
+		py_val = py_new_Boolean_object (value_get_as_checked_bool (val));
 		break;
 	case VALUE_FLOAT:
 		py_val = PyFloat_FromDouble (value_get_as_float (val));
 		break;
 	case VALUE_STRING:
-		py_val = PyString_FromString (val->v_str.val->str);
+		py_val = PyString_FromString (value_peek_string (val));
 		break;
 	case VALUE_CELLRANGE:
 		py_val = py_new_RangeRef_object (&val->v_range.cell);
