@@ -63,6 +63,30 @@ static int rv_allocations;
 #define CHUNK_FREE(p,v) (rv_allocations--, g_slice_free1 (sizeof(*v),(v)))
 #endif
 
+static gboolean
+debug_rv (void)
+{
+	static int res = -1;
+	if (res == -1) {
+		res = gnm_debug_flag ("rendered-value");
+	}
+	return res > 0;
+}
+
+/*
+ * Some valgrind versions have a hard time with signed bitfields,
+ * such as GnmRenderedValue::rotation.
+ */
+static gboolean
+valgrind_bitfield_workarounds (void)
+{
+	static int res = -1;
+	if (res == -1) {
+		res = gnm_debug_flag ("valgrind-bitfield-workarounds");
+	}
+	return res > 0;
+}
+
 
 static guint16
 calc_indent (PangoContext *context, const GnmStyle *mstyle)
@@ -220,12 +244,18 @@ gnm_rendered_value_new (GnmCell const *cell,
 	GnmStyle const *mstyle;
 	PangoDirection dir;
 	char const *text;
+	gboolean debug = debug_rv ();
 
 	g_return_val_if_fail (cell != NULL, NULL);
 
 	/* sheet->workbook can be NULL when called from preview-grid.c  */
 	sheet = cell->base.sheet;
 
+	if (debug)
+		g_printerr ("Rendering %s value [%s]\n",
+			    cell_name (cell),
+			    value_peek_string (cell->value));
+
 	displayed_formula =
 		gnm_cell_has_expr (cell) && sheet->display_formulas;
 
@@ -258,6 +288,11 @@ gnm_rendered_value_new (GnmCell const *cell,
 
 		rrv = CHUNK_ALLOC (GnmRenderedRotatedValue, rendered_rotated_value_pool);
 		res = &rrv->rv;
+		if (valgrind_bitfield_workarounds ()) {
+			memset (&res->go_fore_color + 1,
+				0,
+				(char *)(res + 1) - (char *)(&res->go_fore_color + 1));
+		}
 
 		rrv->linecount = 0;
 		rrv->lines = NULL;
@@ -314,6 +349,9 @@ gnm_rendered_value_new (GnmCell const *cell,
 			double font_size, scale = 1., tscale;
 			int rise = 0;
 
+			if (debug)
+				g_printerr ("  Markup on value: %s\n", go_format_as_XL (fmt));
+
 			attrs = pango_attr_list_copy (attrs);
 
 			iter = pango_attr_list_get_iterator (attrs);
