@@ -113,6 +113,23 @@ sub dump_indented {
     print STDERR $txt;
 }
 
+sub find_program {
+    my ($p) = @_;
+
+    if ($p =~ m{/}) {
+	return $p if -x $p;
+    } else {
+	my $PATH = exists $ENV{'PATH'} ? $ENV{'PATH'} : '';
+	foreach my $dir (split (':', $PATH)) {
+	    $dir = '.' if $dir eq '';
+	    my $tentative = "$dir/$p";
+	    return $tentative if -x $tentative;
+	}
+    }
+
+    &report_skip ("$p is missing");
+}
+
 # -----------------------------------------------------------------------------
 
 sub message {
@@ -382,6 +399,7 @@ sub test_roundtrip {
     if ($resize) {
 	$file_resized =~ s{^.*/}{};
 	$file_resized =~ s/(\.gnumeric)$/-resize$1/;
+	unlink $file_resized;
 	my $cmd = "$ssconvert --resize $resize '$file' '$file_resized'";
 	print STDERR "# $cmd\n" if $verbose;
 	$code = system ("$cmd 2>&1 | sed -e 's/^/| /'");
@@ -390,6 +408,7 @@ sub test_roundtrip {
     }
     
     my $tmp1 = "$tmp.$newext";
+    unlink $tmp1;
     &junkfile ($tmp1) unless $keep;
     {
 	my $cmd = "$ssconvert -T $format '$file_resized' '$tmp1'";
@@ -399,6 +418,7 @@ sub test_roundtrip {
     }
 
     my $tmp2 = "$tmp-new.$ext";
+    unlink $tmp2;
     &junkfile ($tmp2) unless $keep;
     {
 	my $cmd = "$ssconvert '$tmp1' '$tmp2'";
@@ -408,11 +428,13 @@ sub test_roundtrip {
     }
 
     my $tmp_xml = "$tmp.xml";
+    unlink $tmp_xml;
     &junkfile ($tmp_xml) unless $keep;
     $code = system ("zcat -f '$file_resized' | $normalize_gnumeric | $filter1 >'$tmp_xml'");
     &system_failure ('zcat', $code) if $code;
 
     my $tmp2_xml = "$tmp-new.xml";
+    unlink $tmp2_xml;
     &junkfile ($tmp2_xml) unless $keep;
     # print STDERR "zcat -f '$tmp2' | $normalize_gnumeric | $filter2 >'$tmp2_xml'\n";
     $code = system ("zcat -f '$tmp2' | $normalize_gnumeric | $filter2 >'$tmp2_xml'");
