@@ -16,8 +16,7 @@ my $file = "$samples/validation-tests.gnumeric";
 &test_roundtrip ($file,
 		 'format' => 'Gnumeric_OpenCalc:odf',
 		 'ext' => "ods",
-		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'",
-		 'ignore_failure' => 1);
+		 'filter2' => "$PERL -p -e '\$_ = \"\" if m{<meta:generator>}'");
 
 my $xls_codepage_filter = "$PERL -p -e '\$_ = \"\" if m{<meta:user-defined meta:name=.msole:codepage.}'";
 
